@@ -237,8 +237,8 @@ public:
       array->SetHorizontalCount(2);
       array->SetSpace(false,false);
 
-      array->Add(Lum::Button::Create(L"_Clear",clearAction,true,true));
-      array->Add(Lum::Toggle::Create(L"Mark",mark,true,true));
+      array->Add(Lum::Button::Create(_(L"MAIN_CLEAR",L"Clear"),clearAction,true,true));
+      array->Add(Lum::Toggle::Create(_(L"MAIN_MARK",L"Mark"),mark,true,true));
 
       vert->Add(array);
 
@@ -253,21 +253,21 @@ public:
     array->SetHorizontalCount(3);
     array->SetSpace(false,false);
 
-    if (statisticsImage.Valid()) {
+    if (statisticsImage->IsValid()) {
       array->Add(Lum::Button::Create(Lum::Image::Create(statisticsImage),statAction,true,false));
     }
     else {
       array->Add(Lum::Button::Create(_(L"GAME_STAT",L"S_tatistics"),statAction,true,false));
     }
 
-    if (solveImage.Valid()) {
+    if (solveImage->IsValid()) {
       array->Add(Lum::Button::Create(Lum::Image::Create(solveImage),solveAction,true,false));
     }
     else {
       array->Add(Lum::Button::Create(_(L"SOLVE",L"_Solve"),solveAction,true,false));
     }
 
-    if (generateImage.Valid()) {
+    if (generateImage->IsValid()) {
       array->Add(Lum::Button::Create(Lum::Image::Create(generateImage),generateAction,true,false));
     }
     else {
